@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: askaccount.h 433 2008-01-12 08:58:57Z martin $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -22,6 +22,9 @@ class KBanking;
 #include "askaccount.ui.h"
 #include <qstring.h>
 
+#include <aqbanking/account.h>
+
+
 
 class AskAccount: public AskAccountUi {
   Q_OBJECT
@@ -30,6 +33,7 @@ public:
              const char *bankCode,
 	     const char *accountId,
 	     const char *accountName,
+             AB_ACCOUNT_TYPE t,
              QWidget* parent=0,
              const char* name=0,
              bool modal=FALSE,
@@ -51,6 +55,7 @@ private:
   QString _bankCode;
   QString _accountId;
   QString _accountName;
+  AB_ACCOUNT_TYPE _accountType;
 };
 
 
