@@ -333,26 +333,6 @@ int KBanking::init(){
   }
   _sampleReportModules();
 
-  rv=lockSharedConfig("certs", 0);
-  if (rv<0) {
-    DBG_ERROR(0, "ERROR: Could not lock certs db (%d)", rv);
-  }
-  else {
-    GWEN_DB_NODE *dbCerts=NULL;
-
-    rv=loadSharedConfig("certs", &dbCerts, 0);
-    if (rv<0) {
-      DBG_ERROR(0, "ERROR: Could not load certs (%d)", rv);
-    }
-    else {
-      getGui()->setDbCerts(dbCerts);
-    }
-    rv=unlockSharedConfig("certs", 0);
-    if (rv<0) {
-      DBG_ERROR(0, "ERROR: Could not unlock certs db (%d)", rv);
-    }
-  }
-
   return 0;
 }
 
@@ -360,7 +340,6 @@ int KBanking::init(){
 
 int KBanking::fini(){
   GWEN_DB_NODE *dbConfig;
-  GWEN_DB_NODE *dbCerts;
   int rv;
 
   dbConfig=GWEN_DB_Group_new("config");
@@ -383,25 +362,6 @@ int KBanking::fini(){
     return rv;
   }
 
-  /* store certificates */
-  dbCerts=getGui()->getDbCerts();
-  if (dbCerts) {
-    rv=lockSharedConfig("certs", 0);
-    if (rv<0) {
-      DBG_ERROR(0, "ERROR: Could not lock certs db (%d)", rv);
-    }
-    else {
-      rv=saveSharedConfig("certs", dbCerts, 0);
-      if (rv<0) {
-	DBG_ERROR(0, "ERROR: Could not save certs (%d)", rv);
-      }
-      rv=unlockSharedConfig("certs", 0);
-      if (rv<0) {
-	fprintf(stderr, "ERROR: Could not unlock certs db (%d)\n", rv);
-      }
-    }
-  }
-
   return App::fini();
 }
 
@@ -1362,7 +1322,7 @@ int KBanking::_newDatedTransferJob(RefPointer<Transaction> tmpl,
     Account *acc;
 
     b=EditTransaction::createDatedTransfer(this, t,
-					   tr("New Dated Transfer"),
+					   QWidget::tr("New Dated Transfer"),
 					   parent, true);
     if (!b) {
       DBG_INFO(0, "User aborted");
@@ -1393,11 +1353,11 @@ int KBanking::_newDatedTransferJob(RefPointer<Transaction> tmpl,
     if (!ba) {
       DBG_ERROR(0, "Account not available");
       QMessageBox::critical(parent,
-			    tr("Account Not Available"),
-			    tr("The account you requested is not "
+			    QWidget::tr("Account Not Available"),
+			    QWidget::tr("The account you requested is not "
                                "available\n"
                                "with any backend."),
-                            tr("Dismiss"), QString::null);
+                            QWidget::tr("Dismiss"), QString::null);
       return -1;
     }
 
@@ -1407,11 +1367,11 @@ int KBanking::_newDatedTransferJob(RefPointer<Transaction> tmpl,
     if (rv) {
       DBG_NOTICE(0, "Job is not available (%d)", rv);
       QMessageBox::critical(parent,
-                            tr("Job Not Available"),
-                            tr("The job you requested is not "
+                            QWidget::tr("Job Not Available"),
+                            QWidget::tr("The job you requested is not "
                                "available with\n"
                                "the backend which handles parent account.\n"),
-                            tr("Dismiss"), QString::null);
+                            QWidget::tr("Dismiss"), QString::null);
       AB_Job_free(job);
       return -1;
     }
@@ -1425,8 +1385,8 @@ int KBanking::_newDatedTransferJob(RefPointer<Transaction> tmpl,
     case AB_BankInfoCheckResult_NotOk:
       DBG_INFO(0, "Account check result: %d", res);
       i=QMessageBox::warning(parent,
-                             tr("Warning"),
-                             tr("<qt>"
+                             QWidget::tr("Warning"),
+                             QWidget::tr("<qt>"
                                 "<p>"
                                 "The given bank code and account number "
                                 "combination is invalid."
@@ -1446,8 +1406,8 @@ int KBanking::_newDatedTransferJob(RefPointer<Transaction> tmpl,
     case AB_BankInfoCheckResult_UnknownBank:
       DBG_INFO(0, "Account check result: %d", res);
       i=QMessageBox::warning(parent,
-                             tr("Warning"),
-                             tr("<qt>"
+                             QWidget::tr("Warning"),
+                             QWidget::tr("<qt>"
                                 "<p>"
                                 "The given bank code is invalid."
                                 "</p>"
@@ -1483,8 +1443,8 @@ int KBanking::_newDatedTransferJob(RefPointer<Transaction> tmpl,
       if (rv) {
         DBG_NOTICE(0, "Could not set transfer (%d)", rv);
         int res = QMessageBox::critical(parent,
-                                  tr("Bad Transfer Data"),
-                                  tr("<qt>"
+                                  QWidget::tr("Bad Transfer Data"),
+                                  QWidget::tr("<qt>"
                                      "<p>"
                                      "There seems to be some errors "
                                      "in the dated transfer data."
