@@ -241,9 +241,9 @@ int App::init() {
   }
   if (_categories.empty()) {
     rv=_loadCategoryFile(CATEGORYDIR "/gnucash-full.dbConfig");
-    DBG_INFO(0, "Error loading categories (%d)", rv);
-    GWEN_DB_Group_free(dbConfig);
-    return rv;
+    if (rv) {
+      DBG_INFO(0, "Error loading categories (%d), ignoring", rv);
+    }
   }
   if (_categories.empty()) {
     Category *cat;
@@ -907,11 +907,11 @@ bool App::updateAccountList() {
     if (!a) {
       /* account is new, create it */
       a=new Account(this, *it);
-      DBG_INFO(0, "Importing account");
+      DBG_ERROR(0, "Importing account");
       _accounts.push_back(a);
     }
     else {
-      DBG_INFO(0, "Account already exists");
+      DBG_ERROR(0, "Account already exists");
       a->setBankingId(AB_Account_GetUniqueId(*it));
     }
   }
