@@ -209,9 +209,9 @@ AB_TRANSACTION *Transaction::toBankingTransaction() {
   if (!_localAccountNumber.empty())
     AB_Transaction_SetLocalAccountNumber(t, _localAccountNumber.c_str());
   if (!_localIban.empty())
-    AB_Transaction_SetRemoteIban(t, _localIban.c_str());
+    AB_Transaction_SetLocalIban(t, _localIban.c_str());
   if (!_localBic.empty())
-    AB_Transaction_SetRemoteBic(t, _localBic.c_str());
+    AB_Transaction_SetLocalBic(t, _localBic.c_str());
   if (!_localSuffix.empty())
     AB_Transaction_SetLocalSuffix(t, _localSuffix.c_str());
   if (!_localOwnerName.empty())
@@ -1005,6 +1005,10 @@ bool Transaction::toDb(GWEN_DB_NODE *db) const {
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                          "localBic", _localBic.c_str());
 
+  if (!_localOwnerName.empty())
+    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+                         "localName", _localOwnerName.c_str());
+
   if (!_remoteCountry.empty())
     GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
                          "remoteCountry", _remoteCountry.c_str());
@@ -1125,6 +1129,7 @@ bool Transaction::fromDb(GWEN_DB_NODE *db) {
   _localAccountNumber=GWEN_DB_GetCharValue(db, "localAccountNumber", 0, "");
   _localIban=GWEN_DB_GetCharValue(db, "localIban", 0, "");
   _localBic=GWEN_DB_GetCharValue(db, "localBic", 0, "");
+  _localOwnerName=GWEN_DB_GetCharValue(db, "localName", 0, "");
 
   _remoteCountry=GWEN_DB_GetCharValue(db, "remoteCountry", 0, "");
   _remoteBankCode=GWEN_DB_GetCharValue(db, "remoteBankCode", 0, "");
