@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: transactionview.cpp 401 2007-01-15 22:13:48Z martin $
+    cvs         : $Id$
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -150,73 +150,74 @@ TransactionView::~TransactionView(){
 
 
 bool TransactionView::init(){
-  GWEN_DB_NODE *db;
+  GWEN_DB_NODE *dbConfig=NULL;
+  int rv;
   std::string s;
   int i, j;
+  std::string path;
 
   //transactionListView->beginModify();
 
   daySpin->setValue(DEFAULT_NUMDAYS);
 
-  db=_app->getAppData();
-  if (db) {
-    db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                        "gui/views/transactionview");
-    if (db) {
-      if (_account) {
-	s=_account->getBankCode();
-	if (!s.empty()) {
-	  db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-			      s.c_str());
-	  if (db) {
-	    s=_account->getAccountNumber();
-	    if (!s.empty()) {
-	      db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-				  s.c_str());
-	    }
-	  }
-	}
-      }
-      else {
-        if (_tname)
-          db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                              _tname);
-        else
-          db=GWEN_DB_GetGroup(db, GWEN_PATH_FLAGS_NAMEMUSTEXIST,
-                              "generic");
-      }
+  path="gui/views/transactionview";
+  if (_account) {
+    s=_account->getBankCode();
+    if (!s.empty()) {
+      path+="/";
+      path+=s;
+    }
+    s=_account->getAccountNumber();
+    if (!s.empty()) {
+      path+="/";
+      path+=s;
+    }
+  }
+  else if (_tname) {
+    path+="/";
+    path+=_tname;
+  }
+  else {
+    path+="/generic";
+  }
 
-      if (db) {
-	int w;
-	int h;
-	const char *p;
+  rv=_app->loadAppSubConfig(path.c_str(),
+			    &dbConfig,
+			    0);
+  if (rv<0) {
+    DBG_INFO(0, "here (%d)", rv);
+  }
+  else {
+    int w;
+    int h;
+    const char *p;
 
-	/* found settings */
-	p=GWEN_DB_GetCharValue(db, "sortOrder", 0, "ascending");
-	if (p) {
-	  if (strcasecmp(p, "ascending")==0)
-	    transactionListView->setSortOrder(Qt::Ascending);
-	  else
-	    if (strcasecmp(p, "descending")==0)
-	      transactionListView->setSortOrder(Qt::Descending);
-	}
-	i=GWEN_DB_GetIntValue(db, "sortColumn", 0, -1);
-	if (i!=-1)
-	  transactionListView->setSortColumn(i);
-	w=GWEN_DB_GetIntValue(db, "width", 0, 640);
-	h=GWEN_DB_GetIntValue(db, "height", 0, 480);
-	resize(w, h);
-	for (i=0; i<transactionListView->columns(); i++) {
-	  transactionListView->setColumnWidthMode(i, QListView::Manual);
-	  j=GWEN_DB_GetIntValue(db, "columns", i, -1);
-	  if (j!=-1)
-	    transactionListView->setColumnWidth(i, j);
-	} /* for */
-        daySpin->setValue(GWEN_DB_GetIntValue(db, "numDays", 0,
-                                              DEFAULT_NUMDAYS));
-      } // db
-    } // if transaction view setting
+    /* found settings */
+    p=GWEN_DB_GetCharValue(dbConfig, "sortOrder", 0, "ascending");
+    if (p) {
+      if (strcasecmp(p, "ascending")==0)
+	transactionListView->setSortOrder(Qt::Ascending);
+      else
+	if (strcasecmp(p, "descending")==0)
+	  transactionListView->setSortOrder(Qt::Descending);
+    }
+    i=GWEN_DB_GetIntValue(dbConfig, "sortColumn", 0, -1);
+    if (i!=-1)
+      transactionListView->setSortColumn(i);
+    w=GWEN_DB_GetIntValue(dbConfig, "width", 0, 640);
+    h=GWEN_DB_GetIntValue(dbConfig, "height", 0, 480);
+    resize(w, h);
+    for (i=0; i<transactionListView->columns(); i++) {
+      transactionListView->setColumnWidthMode(i, QListView::Manual);
+      j=GWEN_DB_GetIntValue(dbConfig, "columns", i, -1);
+      if (j!=-1)
+	transactionListView->setColumnWidth(i, j);
+    } /* for */
+    daySpin->setValue(GWEN_DB_GetIntValue(dbConfig, "numDays", 0,
+					  DEFAULT_NUMDAYS));
+    GWEN_DB_Group_free(dbConfig);
   } // if application settings
+
   slotUpdated();
   //transactionListView->endModify();
   return true;
@@ -225,56 +226,53 @@ bool TransactionView::init(){
 
 
 bool TransactionView::fini(){
-  GWEN_DB_NODE *db;
+  GWEN_DB_NODE *dbConfig;
+  int rv;
+  std::string path;
   int i, j;
   std::string s;
 
-  db=_app->getAppData();
-  assert(db);
-  db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-                      "gui/views/transactionview");
-  assert(db);
+  path="gui/views/transactionview";
   if (_account) {
     s=_account->getBankCode();
     if (!s.empty()) {
-      db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_DEFAULT,
-			  s.c_str());
-      assert(db);
-      s=_account->getAccountNumber();
-      if (!s.empty()) {
-	db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_OVERWRITE_GROUPS,
-			    s.c_str());
-	assert(db);
-      }
+      path+="/";
+      path+=s;
+    }
+    s=_account->getAccountNumber();
+    if (!s.empty()) {
+      path+="/";
+      path+=s;
     }
-  } // if _account
-  else {
-    if (_tname)
-      db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_OVERWRITE_GROUPS,
-                          _tname);
-    else
-      db=GWEN_DB_GetGroup(db, GWEN_DB_FLAGS_OVERWRITE_GROUPS,
-                          "generic");
   }
-  assert(db);
+  else if (_tname) {
+    path+="/";
+    path+=_tname;
+  }
+  else {
+    path+="/generic";
+  }
 
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+  dbConfig=GWEN_DB_Group_new("config");
+  assert(dbConfig);
+
+  GWEN_DB_SetIntValue(dbConfig, GWEN_DB_FLAGS_OVERWRITE_VARS,
 		      "width", width());
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+  GWEN_DB_SetIntValue(dbConfig, GWEN_DB_FLAGS_OVERWRITE_VARS,
 		      "height", height());
 
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+  GWEN_DB_SetIntValue(dbConfig, GWEN_DB_FLAGS_OVERWRITE_VARS,
 		      "sortColumn", transactionListView->sortColumn());
-  GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+  GWEN_DB_SetIntValue(dbConfig, GWEN_DB_FLAGS_OVERWRITE_VARS,
 		      "numDays", daySpin->value());
 
   switch(transactionListView->sortOrder()) {
   case Qt::Ascending:
-    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+    GWEN_DB_SetCharValue(dbConfig, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			 "sortOrder", "ascending");
     break;
   case Qt::Descending:
-    GWEN_DB_SetCharValue(db, GWEN_DB_FLAGS_OVERWRITE_VARS,
+    GWEN_DB_SetCharValue(dbConfig, GWEN_DB_FLAGS_OVERWRITE_VARS,
 			 "sortOrder", "descending");
     break;
   default:
@@ -283,10 +281,19 @@ bool TransactionView::fini(){
 
   for (i=0; i<transactionListView->columns(); i++) {
     j=transactionListView->columnWidth(i);
-    GWEN_DB_SetIntValue(db, GWEN_DB_FLAGS_DEFAULT,
+    GWEN_DB_SetIntValue(dbConfig, GWEN_DB_FLAGS_DEFAULT,
 			"columns", j);
   } /* for */
 
+  rv=_app->saveAppSubConfig(path.c_str(),
+			    dbConfig,
+			    0);
+  GWEN_DB_Group_free(dbConfig);
+  if (rv<0) {
+    DBG_INFO(0, "here (%d)", rv);
+    return false;
+  }
+
   return true;
 }
 
