@@ -618,7 +618,7 @@ void TransactionListView::addTransactions(const std::list<RefPointer<Transaction
     pd->setCaption(tr("Working..."));
     pd->setMinimumDuration(/*100*/ 0);
   }
-  DBG_DEBUG(0, "Adding transactions to list view (%d)", ts.size());
+  DBG_DEBUG(0, "Adding transactions to list view (%d)", int(ts.size()));
   tiLast=0;
   n=0;
 
