@@ -143,7 +143,7 @@ int test2(int argc, char **argv) {
     lv->setColumnWidth(i, 10);
   a.setMainWidget(lv);
   xl=account->getTransactions();
-  DBG_ERROR(0, "Got %d transactions", xl.size());
+  DBG_ERROR(0, "Got %d transactions", int(xl.size()));
   DBG_ERROR(0, "Adding transactions...");
   lv->setDrawMode(RichTextListView::DrawMode_Fastest);
   startTime=QTime::currentTime();
@@ -210,7 +210,7 @@ int test3(int argc, char **argv) {
     lv->setColumnWidth(i, 10);
   a.setMainWidget(lv);
   xl=account->getTransactions();
-  DBG_ERROR(0, "Got %d transactions", xl.size());
+  DBG_ERROR(0, "Got %d transactions", int(xl.size()));
   DBG_ERROR(0, "Adding transactions...");
   startTime=QTime::currentTime();
   lv->addTransactions(xl);
@@ -271,7 +271,7 @@ int test4(int argc, char **argv) {
   account=kb->findAccount("28250110", "0002728194");
   assert(account);
   xl=account->getTransactions();
-  DBG_ERROR(0, "Got %d transactions", xl.size());
+  DBG_ERROR(0, "Got %d transactions", int(xl.size()));
   lv=new TransactionView(kb, xl);
   a.setMainWidget(lv);
   lv->init();
